
(function($) {

	"use strict"

	window.wp = window.wp || {};
	var document = window.document;
	var $ = window.jQuery;
	var ctor, inherits;
	var api = {};

	ctor = function() {};

	inherits = function( parent, protoProps, staticProps ) {
		var child;
		if ( protoProps && protoProps.hasOwnProperty( 'constructor' ) ) {
			child = protoProps.constructor;
		} else {
			child = function() {
				var result = parent.apply( this, arguments );
				return result;
			};
		}

		$.extend( child, parent );

		ctor.prototype  = parent.prototype;
		child.prototype = new ctor();

		if ( protoProps ) {
			$.extend( child.prototype, protoProps );
		}

		if ( staticProps ) {
			$.extend( child, staticProps );
		}

		child.prototype.constructor = child;
		child.__super__ = parent.prototype;

		return child;
	};

	api.Class = function( applicator, argsArray, options ) {
		var magic, args = arguments;

		if ( applicator && argsArray && api.Class.applicator === applicator ) {
			args = argsArray;
			$.extend( this, options || {} );
		}

		magic = this;
		if ( this.instance ) {
			magic = function() {
				return magic.instance.apply( magic, arguments );
			};

			$.extend( magic, this );
		}

		magic.initialize.apply( magic, args );

		return magic;
	};

	api.Class.extend = function( protoProps, classProps ) {
		var child = inherits( this, protoProps, classProps );
		child.extend = this.extend;

		return child;
	};

	api.Class.applicator = {};
	api.Class.prototype.initialize = function() {};
	api.Class.prototype.extended = function( constructor ) {
		var proto = this;

		while ( typeof proto.constructor !== 'undefined' ) {
			if ( proto.constructor === constructor ) {
				return true;
			}

			if ( typeof proto.constructor.__super__ === 'undefined' ) {
				return false;
			}

			proto = proto.constructor.__super__;
		}

		return false;
	};

	api.settings = knowhere_job_manager_localize;
	api.controllers = {};
	api.DataServices = [];
	api.DataService = api.Class.extend({
		response: null,
		activeResponse: $.Deferred(),
		resultsContainer: 'ul.job_listings',
		initialize: function( options ) {
			$.extend( this, options || {} );
		},
		geocoder: null,
		auto: null,
		update: function() {},
		addResults: function( resultsContainer ) {
			var self = this;
			self.setFound();
		},
		setFound: function() {
			var found = api.controllers.dataService.response.found_posts ? api.controllers.dataService.response.found_posts : 0;
			$('.kw-results-count').replaceWith('<div class="kw-results-count">'+ api.settings.i18n.resultsFound.replace( '%d', found ) +'</div>');
		}
	});

	api.DataServices.Job = api.DataService.extend({

		initialize: function( options ) {

			api.DataService.prototype.initialize.call( options );

			this.geocoder = new google.maps.Geocoder();
			this.isAddressGeocoded = false;
			this.prevAddress = $( '#search_location' ).val();
			this.$target = $( 'div.job_listings' );
			this.$form = $( 'form.job_filters' );
			this.$address = $( '#search_location' );
			this.$lat = $( '#search_lat' );
			this.$lng = $( '#search_lng' );
			this.auto = 'search_location';

			this.resultsContainer = this.$target.find( 'ul.job_listings' );

			this.radiusSlider();

			this.locateMe();

			if ( 0 === this.$target.length ) {
				return;
			}

			var self = this;

			this.$target.on( 'updated_results', function( event, data ) {

				self.response = data;

				if ( ! self.activeResponse.state( 'resolved' ) ) {
					if ( window.console ) {
						console.log( 'Data Service ready...' );
					}
				} else {
					self.addResults();
				}

			} );

			this.$target.on( 'update_results', function(e) {
				self.maybeReverseGeocode();
			} );
		},

		maybeReverseGeocode: function() {
			if ( ! api.controllers.dataService ) {
				return;
			}

			if ( ! api.controllers.dataService.geocode ) {
				return;
			}

			if ( '' === this.$address.val() ) {
				return;
			}

			if ( this.$address.val() != this.prevAddress ) {
				this.isAddressGeocoded = false;
			}

			if ( this.isAddressGeocoded || this.isAddressGeocoding ) {
				return;
			}

			api.controllers.dataService.geocode( this.$address.val() );
		},

		radiusSearch: function( lat, lng ) {
			this.$lat.val( lat );
			this.$lng.val( lng );

			this.update();
		},

		radiusSlider: function() {
			var self = this;

			var min_radius = parseInt(knowhere_job_manager_localize.min_radius);
			var max_radius = parseInt(knowhere_job_manager_localize.max_radius);
			var default_radius = parseInt(knowhere_job_manager_localize.default_radius);

			var radius_search_slider = function( default_radius ) {

				$('#radius-range-slider').slider({
					value: default_radius,
					min: min_radius,
					max: max_radius,
					step: 1,
					slide: function (event, ui) {
						self.updateRadius(ui);
					},
					change: function (event, ui) {
						self.update();
					},
					stop: function( event, ui ) { }
				});

				$( '.radi' ).html( $('#radius-range-slider' ).slider('value'));
				$( '#search_radius' ).val( $('#radius-range-slider' ).slider('value'));
			}

			if ( $( '#radius-range-slider' ).length > 0 ) {
				radius_search_slider(default_radius);
			}

		},

		update: function() {
			this.$target.triggerHandler( 'update_results', [ 1, false ] );
		},

		updateRadius: function( ui ) {
			$('.radi').html(ui.value);
			$('#search_radius').val(ui.value);
		},

		locateMe: function() {

			if ( ! navigator.geolocation ) {
				return;
			}

			var self = this;

			$( '.search_location' ).append( '<i class="kw-locate-me"></i>' );

			$( '.kw-locate-me' ).on( $.knowhere.EVENT, function( e ) {
				e.preventDefault();

				$(this).addClass( 'loading' );

				navigator.geolocation.getCurrentPosition( self.locateMeSuccess, null, {
					enableHighAccuracy: true
				});
			});

		},

		locateMeSuccess: function( position ) {
			var lat = position.coords.latitude;
			var lng = position.coords.longitude;

			if ( api.controllers.dataService.geocode ) {
				api.controllers.dataService.geocode( lat + ', ' + lng );
			}

			$( '.kw-locate-me' ).removeClass( 'loading' );
		},

		autoComplete: function( field ) {
			var self = this;

			var $field = $( '#' + field );

			if ( 0 === $field.length ) {
				return;
			}

			var autocomplete = new google.maps.places.Autocomplete( document.getElementById( field ), {
				types: ['geocode']
			} );

			$field.unbind( 'change' );

			$field.keypress(function( e ) {
				if ( e.which == 13 ) {
					api.controllers.dataService.update();
				}
			});

			autocomplete.addListener( 'place_changed', function() {
				var place = autocomplete.getPlace();

				if ( place.geometry ) {
					api.controllers.dataService.isAddressGeocoded = true;
					api.controllers.dataService.radiusSearch( place.geometry.location.lat(), place.geometry.location.lng() );
				} else {
					api.controllers.dataService.isAddressGeocoded = false;
					self.geocode( place.name );
				}
			} );

		},

		geocode: function( address ) {
			this.isAddressGeocoding = true;

			this.geocoder.geocode({
				address: address
			}, function( results, status ) {

				if ( status == google.maps.GeocoderStatus.OK ) {
					var loc = results[0].geometry.location;

					api.controllers.dataService.prevAddress = address;
					api.controllers.dataService.isAddressGeocoded = true;
					api.controllers.dataService.$address.val( results[0].formatted_address );

					api.controllers.dataService.radiusSearch( loc.lat(), loc.lng() );
				} else {
					api.controllers.dataService.isAddressGeocoded = false;
				}

				this.isAddressGeocoding = false;
			} );
		}

	});

	function knowhere_empty (data) {
		if ( typeof( data ) == 'number' || typeof( data ) == 'boolean' ) { return false; }
		if ( typeof( data ) == 'undefined' || data === null ) { return true; }
		if ( typeof( data.length ) != 'undefined' ) { return data.length === 0; }
		var count = 0;
		for ( var i in data ) {
			if ( Object.prototype.hasOwnProperty.call(data, i) ) { count++; }
		}
		return count === 0;
	}

	function customizePadding (window) {

		var $content = $('.kw-page-listings:not(.kw-page-add-listing) .kw-content-area'),
			$pageContent = $('.kw-page-content.kw-right-sidebar, .kw-page-content.kw-no-sidebar'),
			$pageListings = $('.kw-page-listings'),
			$map = $pageListings.find('.kw-listings-gmap'),
			$header = $pageListings.find('.kw-header'),
			$leftPosition = $pageListings.find('.kw-left-position'),
			$headerTop = $pageListings.find('.kw-header-top'),
			flexRight = $pageListings.find('.kw-flex-right'),
			finderSearch = $('.kw-finder-filters'),
			finderListings = $('.kw-finder-listings'),
			finderExtend = $('.kw-finder-extend'),
			headerHeight = $header.outerHeight(),
			headerHeightWithAdminBar = headerHeight,
			position = headerHeight;

		if ( $pageContent.length ) {
			$content = $pageContent;
		}

		if ( !$pageListings.length ) return;


		if ( finderExtend.length && $leftPosition.hasClass('kw-left-position-extend') ) {
			position = finderExtend.position().top + 30;
		}

		if ( window.width() < 993 || $pageListings.hasClass('kw-page-add-listing') || $pageListings.hasClass('kw-has-no-listings') ) {
			$content.css( 'marginTop', '' );
			return;
		}

		if ( $('#wpadminbar').length ) {
			headerHeightWithAdminBar += $('#wpadminbar').outerHeight();
		}

		if ( $headerTop.length ) {
			$headerTop.css( { 'height': headerHeightWithAdminBar } );
		}

		if ( $header.css('position') == 'fixed' || $header.css('position') == 'absolute' ) {
			$content.css( 'marginTop', headerHeightWithAdminBar );
		}

		if ( $leftPosition.length && !$leftPosition.hasClass('kw-left-position-extend') ) {

			if ( finderSearch.length && finderListings.length && flexRight.length ) {
				finderSearch.add(finderListings).add(flexRight).css({'height': 'calc(100vh - ' + headerHeightWithAdminBar + 'px)'});
			}

		} else if ( $leftPosition.hasClass('kw-left-position-extend') && !$map.hasClass('kw-flex-full-width') ) {
			$map.css('top', position);
		} else if ( $map.hasClass('kw-flex-full-width' ) ) {

		} else {
			$map
				.css( 'top', headerHeightWithAdminBar )
				.css({'height': 'calc(100vh - ' + headerHeightWithAdminBar + 'px)'});
		}

	}

	function eventHanlers() {

		var window = $(window);

		window.on('debouncedresize', function() {

			customizePadding($(this));

			setTimeout(function() {
				window.trigger('update:map');
				window.trigger('pxg:refreshmap');
			});

		});

	}

	var Map = (
		function () {

			var $body = $('body'),
				$window = $(window),
				map, markers, custom_html_icon;

			function init() {

				customizePadding($window);
				eventHanlers();

				if ( !$('#kw-listings-gmap').length ) {
					$('.job_listings').on('updated_results', function(e, result) {
						updateListing(result.total_found);
					});
					return;
				}

				if ( typeof L !== "object" || !L.hasOwnProperty('map') ) {
					return;
				}

				var bounds = Cookies.get('kw-bounds');

				if ( typeof bounds === 'undefined' ) {
					bounds = [46.073085, 14.450286];
				} else {
					bounds = JSON.parse(bounds);
				}

				map = L.map('kw-listings-gmap', {
					scrollWheelZoom: false,
					zoomControl: true,
					setView: true,
					fullscreenControl: true
				});

				map.setView(bounds, 9);

				var mapStyle = [];

				var style_map = knowhere_job_manager_localize.style_map;

				if ( style_map.length ) {
					mapStyle = (new Function("return [" + style_map+ "];")())[0];
				}

				var options = {
					type: knowhere_job_manager_localize.map_type,
					styles: mapStyle
				}

				map.addLayer( L.gridLayer.googleMutant(options) );

				markers = new L.MarkerClusterGroup({
					showCoverageOnHover: false
				});

				custom_html_icon = L.HtmlIcon.extend({
					options: {
						iconSize: [50, 60],
						iconAnchor: [25, 60],
						popupAnchor: [-1, -60]
					}
				});

				$window.on('pxg:refreshmap', function () {
					map._onResize();
				});
				//
				if ( !$('#kw-listings-gmap').is('.kw-listing-widget-gmap') ) {

					// updateListing();

					$('.job_listings').on('updated_results', function(e, result) {
						updateListing(result.total_found);
					});

					$(document).on('facetwp-loaded facetwp-refresh', function(e, result) {
						if ( $('select.facetwp-dropdown').length ) {
							$('select.facetwp-dropdown').chosen();
						}
						updateListing();
					});

				}

			}

			function widget_init() {

				if ( typeof L !== "object" || !L.hasOwnProperty('map') ) {
					return;
				}

				var $widget_gmap = $('.kw-listing-widget-gmap');

				if ( $widget_gmap.length ) {

					$widget_gmap.each(function(i, el) {

						var map = L.map(el, {
							scrollWheelZoom: false
						});

						var mapStyle = [];

						var style_map = knowhere_job_manager_localize.style_map;

						if ( style_map.length ) {
							mapStyle = (new Function("return [" + style_map+ "];")())[0];
						}

						var options = {
							type: knowhere_job_manager_localize.map_type,
							styles: mapStyle
						}

						map.addLayer( L.gridLayer.googleMutant(options) );

						markers = new L.MarkerClusterGroup({
							showCoverageOnHover: true
						});

						custom_html_icon = L.HtmlIcon.extend({
							options: {
								iconSize: [50, 60], // size of the icon
								iconAnchor: [25, 60], // point of the icon which will correspond to marker's location
								popupAnchor: [-1, -60] // point from which the popup should open relative to the iconAnchor
							}
						});

						$window.on('pxg:refreshmap', function () {
							map._onResize();
						});

						var $item = $('.single_job_listing');

						if ( typeof $item.data('latitude') !== "undefined" && typeof $item.data('longitude') !== "undefined" ) {

							addPinToMap($item);
							map.addLayer(markers);
							map.setView([$item.data('latitude'), $item.data('longitude')], 13);
							$(window).on('update:map', function() {
								map.setView([$item.data('latitude'), $item.data('longitude')], 13);
							});

						} else {
							$(el).hide();
						}

					});

				}

			}

			function updateListing($total) {

				var $listings = $('.job_listings'),
					$listing = $('.job_listing', $listings),
					listingWithLocation = 0;

				if ( !$listing.length ) {
					return;
				}

				if ( $listing.find('.kw-rating').length ) {
					$.knowhere.templateHelpers.productRating($listing.find('.kw-rating'));
				}

				if ( $listing.find('.kw-share-popup-link').length ) {
					KnowhereJobManager.popupLink($listing.find('.kw-share-popup-link'));
				}

				if ( $listing.find('.kw-property-slideshow.owl-carousel').length ) {
					$.knowhere.templateHelpers.propertySlideshow($listing.find('.kw-property-slideshow.owl-carousel'));
				}

				if ( typeof $total !== 'undefined' ) {
					$('.kw-results-count').replaceWith('<div class="kw-results-count">' + $total + ' ' + knowhere_job_manager_localize.strings['results'] + '</div>');
				} else {
					$('.kw-results-count').replaceWith('<div class="kw-results-count">' + $listing.length + ' ' + knowhere_job_manager_localize.strings['results'] + '</div>');
				}

				if ( $('.kw-listings-gmap').length && typeof map !== "undefined" ) {

					map.removeLayer(markers);

					markers = new L.MarkerClusterGroup({
						showCoverageOnHover: false,
						spiderfyDistanceMultiplier: 3,
						spiderLegPolylineOptions: { weight: 0 }
					});

					$listing.each(function(i, obj) {

						var cardHasLocation = addPinToMap($(obj), true);

						if ( cardHasLocation ) {
							listingWithLocation += 1;
						}
					});

					if ( listingWithLocation != 0 ) {
						map.fitBounds(markers.getBounds(), {
							padding: [50, 50]
						});
						map.addLayer(markers);

						var mapZoom = map.getZoom();
						var bounds = markers.getBounds();
						var lat = (bounds._northEast.lat + bounds._southWest.lat) / 2;
						var lng = (bounds._northEast.lng + bounds._southWest.lng) / 2;
						bounds = [lat, lng];

						Cookies.set('kw-bounds', JSON.stringify(bounds));
						Cookies.set('kw-mapZoom', mapZoom);

					} else {
						defaultMap();
					}
				}

			}

			function addPinToMap($item, tax) {
				var categories = $item.data('categories'),
					iconClass, m, $img, ratingHTML = '';

				if ( typeof categories !== "undefined" && !categories.length ) {
					iconClass = 'kw-pin kw-pin-empty';
				} else {
					iconClass = 'kw-pin';
				}

				iconClass += ' ' + $item.data('first-term-id-class');

				if ( knowhere_empty($item.data('latitude')) || knowhere_empty($item.data('longitude')) ) {
					return false;
				}

				var iconSVG = knowhere_job_manager_localize.pin_style == 'default' ? wp.template('knowhere-pin-selected-svg') : wp.template('knowhere-pin-selected-svg2'),
					emptyiconSVG = knowhere_job_manager_localize.pin_style == 'default' ? wp.template('knowhere-empty-icon-svg') : wp.template('knowhere-empty-icon-svg2'),
					$categories = $item.find('.kw-listing-item-icon').first();

				var iconHTML = "<div class='" + iconClass + "'>" + emptyiconSVG() + "</div>";

				if ( $body.is('.single-job_listing') || $body.is('.kw-page-add-listing') ) {
					if ( $('.kw-single-map-category-icon').length ) {
						iconHTML = "<div class='" + iconClass + "'>" + iconSVG() + "<div class='kw-pin-icon'>" + $('.kw-single-map-category-icon').html() + "</div></div>";
					}
				} else if ( $categories.length ) {
					iconHTML = "<div class='" + iconClass + "'>" + iconSVG() + "<div class='kw-pin-icon'>" + $categories.html() + "</div></div>";
				}

				m = L.marker([$item.data('latitude'), $item.data('longitude')], {
					icon: new custom_html_icon({
						html: iconHTML
					})
				});

				if ( typeof tax !== "undefined" ) {

					if ( knowhere_empty($item.data('img')) ) { } else {
						$img = '<img src="'+ $item.data('img') +'" alt="" />';
					}

					$item.hover(function() {
						$(m._icon).find('.kw-pin').addClass('kw-pin-selected');
					}, function() {
						$(m._icon).find('.kw-pin').removeClass('kw-pin-selected');
					});

					var event = knowhere_job_manager_localize.pintpoint_event ? knowhere_job_manager_localize.pintpoint_event : 'click';

					$item.find('.kw-listing-item-pintpoint')[event](function(e) {
						e.preventDefault();

						map.setView([$item.data('latitude'), $item.data('longitude')], 20);
						$(window).on('update:map', function() {
							map.setView([$item.data('latitude'), $item.data('longitude')], 20);
						});
					});

					var rating = $item.find('.kw-card-rating');

					if ( rating.length ) {
						ratingHTML = rating.length ? rating.html() : "";
					}

					var phone = $item.data('phone') ? '<div class="kw-popup-phone"><a href="tel://' + $item.data('phone') + '">' + $item.data('phone') + '</a></div>' : '';

					m.bindPopup(
						"<div class='kw-popup'><a  href='" + $item.data('permalink') + "'>" + $img + "</a>" +
						"<div class='kw-popup-content'>" +
						"<a href='" + $item.data('permalink') + "'><h5 class='kw-popup-title'>" + $item.find('.kw-listing-item-title a').html() + "</h5></a>" + ratingHTML +
						"<div class='kw-popup-address'>" + $item.find('.kw-listing-item-location').html() + "</div>" + phone +
						"<div class='kw-open-hours-status "+ $item.data('open-hours-status') +"'>" + $item.data('open-hours-text') + "</div></div>" +
						"</div>").openPopup();

				}

				markers.addLayer(m);

				return true;
			}

			function defaultMap() {
				var bounds = Cookies.get('kw-bounds'),
					zoom = Cookies.get('kw-mapZoom');

				if ( typeof bounds === 'undefined' ) {
					bounds = [46.073085, 14.450286];
					zoom = 9;
				} else {
					bounds = JSON.parse(bounds);
				}

				map.removeLayer(markers);
				map.setView(bounds, zoom);
			}

			return {
				init: init,
				widget_init: widget_init
			}

		}
	)();

	$(function() {

		function initialize() {

			/* Used on main search page */
			if ( $('#job_location').length || $('#candidate_location').length ) {
				var inputs = $('#job_location, #candidate_location');

				inputs.each(function(index, elem) {
					if ( elem ) {
						new google.maps.places.Autocomplete(elem);
					}
				})
			}

		}

		if ( typeof google === 'object' && typeof google.maps === 'object' ) {
			google.maps.event.addDomListener( window, 'load', initialize );
		}

		api.controllers.dataService = new api.DataServices.Job();

		// Add auto complete if available.
		if ( google.maps.places ) {
			if ( api.controllers.dataService.auto ) {
				api.controllers.dataService.autoComplete( api.controllers.dataService.auto );
			}
		}

	});

	$(window).load(function() {
		Map.init();
		Map.widget_init();
	});

})(jQuery);