if ( typeof chosen == 'undefined') {
	function chosen() {}
}

(function( window, $ ) {

	'use strict';

	function job_manager_supports_html5_session_storage() {
		return window.sessionStorage && typeof window.sessionStorage.setItem === 'function';
	}

	var session_storage_prefix = 'job_listing_';

	function job_manager_get_session_storage_key( $target ) {
		var index          = $( 'div.job_listings' ).index( $target );
		var unique_page_id = $target.data( 'post_id' );

		if ( typeof unique_page_id === 'undefined' || ! unique_page_id ) {
			unique_page_id = window.location.href.replace( location.hash, '' );
		}

		return session_storage_prefix + unique_page_id + '_' + index;
	}


	function job_manager_clear_state( $target ) {
		if ( ! job_manager_supports_html5_session_storage() ) {
			return false;
		}

		var session_storage_key = job_manager_get_session_storage_key( $target );

		try {
			window.sessionStorage.removeItem( session_storage_key );
		} catch ( e ) {
			return false;
		}

		return true;
	}

	job_manager_clear_state($( 'div.job_listings' ));

	function knowhere_empty (data) {
		if ( typeof( data ) == 'number' || typeof( data ) == 'boolean' ) { return false; }
		if ( typeof( data ) == 'undefined' || data === null ) { return true; }
		if ( typeof( data.length ) != 'undefined' ) { return data.length === 0; }
		var count = 0;
		for ( var i in data ) {
			if ( Object.prototype.hasOwnProperty.call(data, i) ) { count++; }
		}
		return count === 0;
	}

	KnowhereJobManager.init = function() {

		KnowhereJobManager.initLayoutControl();
		KnowhereJobManager.searchModule();

		var $uploader = $('.wp-job-manager-file-upload');

		if ( $uploader.length ) {
			$uploader.each(function(i, obj) {
				var $input = $(obj),
					id = $input.attr('id'),
					$label = $('label[for="' + id + '"]'),
					$btn = $('<div class="kw-file-input-field"><div class="kw-file-input-inner"><span class="lnr icon-picture kw-lead-icon"></span><span class="lnr icon-plus"></span>' + knowhere_job_manager_localize.strings['wp-job-manager-file-upload'] + '</div></div>').insertAfter($input);

				$btn.on('click', function() {
					$label.trigger('click');
				});
			});
		}

	}

	KnowhereJobManager.initScroll = function() {

		$(window).on("resize", function() {

			var elements = $('.kw-page-listings:not(.kw-page-add-listing) .kw-left-position:not(.kw-without-map):not(.kw-left-position-extend) .kw-finder-filters, .kw-page-listings:not(.kw-page-add-listing) .kw-left-position:not(.kw-without-map):not(.kw-left-position-extend) .kw-finder-listings');

			if ( !elements.length ) return;

			window.innerWidth >= 993 ? elements.mCustomScrollbar({
				theme: "minimal-dark"
			}) : elements.mCustomScrollbar("destroy");

		}).trigger("resize");

	}

	KnowhereJobManager.searchModule = function() {

		var price_range_min = parseInt( knowhere_job_manager_localize.min_price );
		var price_range_max = parseInt( knowhere_job_manager_localize.max_price );
		var currency_symb = knowhere_job_manager_localize.currency_symbol;
		var thousands_separator = knowhere_job_manager_localize.thousands_separator;
		var is_rtl = knowhere_job_manager_localize.rtl;

		var addCommas = function(nStr) {
			nStr += '';
			var x = nStr.split('.');
			var x1 = x[0];
			var x2 = x.length > 1 ? '.' + x[1] : '';
			var rgx = /(\d+)(\d{3})/;
			while (rgx.test(x1)) {
				x1 = x1.replace(rgx, '$1' + thousands_separator + '$2');
			}
			return x1 + x2;
		}

		if ( $('.knowhere-tags-select').length ) {
			var $tags = $('.knowhere-tags-select').chosen( { rtl: is_rtl } ),
				updateTags = function() {
					$('.knowhere-active-tags').empty();
					$tags.find(':selected').each(function(i, obj) {

						if ( knowhere_empty(obj.value) ) {
							return;
						}

						$('<div class="knowhere-active-tag">' + obj.value + '<div class="knowhere-remove-tag"></div></div>').appendTo('.knowhere-active-tags').on('click', function() {
							$(this).remove();
							$(obj).attr('selected', false);
							$tags.trigger("chosen:updated");
							$('.knowhere-active-tags input[value="' + obj.value + '"]').remove();
							$('.job_listings').triggerHandler('update_results', [1, false]);
						});

						$('<input type="hidden" name="job_tag[]" value="' + obj.value + '" />').appendTo('.knowhere-active-tags');
					});

					$('.job_listings').triggerHandler('update_results', [1, false]);
				};

			$tags.on('change', updateTags);
		}

		if ( $('.search_feature').length ) {
			$('.search_feature').on('change', function () {
				$('.job_listings').triggerHandler('update_results', [1, false]);
			});
		}

		if ( $('.filter-job-regions').length ) {
			var $regions = $('.filter-job-regions').chosen({
					rtl: is_rtl
				}),
				updateRegions = function() {

					$('.knowhere-active-regions').empty();

					$regions.find(':selected').each(function(i, obj) {

						if ( knowhere_empty(obj.value) ) {
							return;
						}

						$('<input type="hidden" name="search_region" value="' + obj.value + '" />').appendTo('.knowhere-active-regions');

					});

					$('.job_listings').triggerHandler('update_results', [1, false]);

				};

			$regions.on('change', updateRegions);
		}

		$('.knowhere-search-jobs-frontpage .job-manager-category-dropdown, .job-manager-dropdown, .search_bedrooms, .search_bathrooms, .job-manager-filter').chosen( { rtl: is_rtl } );

		$( '#job_type' ).chosen({
			rtl: is_rtl,
			search_contains: true
		});

		$( '.kw-finder-filters' ).on( $.knowhere.EVENT, '.reset', function () {
			var target = $(this).closest( 'div.job_listings' );
			var form = target.find( 'form' );

			form.find( ':input[name="search_keywords"], :input[name="search_location"], .job-manager-filter' ).not(':input[type="hidden"]').val( '' ).trigger( 'chosen:updated' );
			form.find( ':input[name^="search_categories"]' ).not(':input[type="hidden"]').val( '' ).trigger( 'chosen:updated' );
			$( ':input[name="filter_job_type[]"]', form ).not(':input[type="hidden"]').attr( 'checked', 'checked' );

			form.find('.min-price-range-hidden, .max-price-range-hidden').val( '' );
			form.find('.knowhere-active-tags, .knowhere-active-regions').empty();
			form.find('.knowhere-tags-select, .filter-job-types, .filter-job-regions').trigger("chosen:updated");

			form.find('.knowhere-tags-select, .filter-job-types, .filter-job-regions, .search_bedrooms, .search_region, .search_bathrooms').find(':selected').each(function(i, e) {
				$(e).attr('selected', false);
			}).end().trigger( 'chosen:updated' );

			form.find('.search_feature:checked').each( function( i, e ) {
				$(e).attr('checked', false);
			});

			form.find('input[name="search_keywords"], .search_bedrooms, .search_region, .search_bathrooms').each(function(i, e) {
				$(e).val('').trigger('chosen:updated');
			});

			var filters_search = target.find('.kw-job-filters-search');
			if ( filters_search.length ) {
				filters_search.empty();
			}

			target.triggerHandler( 'reset' );
			target.triggerHandler( 'update_results', [ 1, false ] );
			// job_manager_store_state( target, 1 );

			return false;
		} );

		function kw_search_keywords() {
			var form_keyword = $('.job_filters input[name="search_keywords"]');
			var value = $('.kw-controls-form input[name="search_keywords"]').val();

			if ( form_keyword.length ) {
				if ( value ) {
					form_keyword.val(value);
				} else {
					form_keyword.val(' ');
				}
			}
		}

		$( '.kw-controls-form input[name="search_keywords"]' ).change( function() {
			kw_search_keywords();
		} );

		$('.kw-search-keywords-btn').on($.knowhere.EVENT, function (e) {
			e.preventDefault();
			kw_search_keywords();

			$( this ).closest( 'div.job_listings' ).triggerHandler( 'update_results', [ 1, false ] );
		});

		function kw_search_sort() {

			var form_sort = $('.job_filters [name^="search_sort"]');
			var selected = $(this).val();

			if ( form_sort.length ) {
				if ( selected ) {

					form_sort.find('option').each(function () {
						$(this).attr('selected', false);
					});

					$('.job_filters [name^="search_sort"] option[value=' + selected + ']').attr('selected', 'selected');

				}
			}

		}

			var price_range = function( min_price, max_price ) {

				$('.price-range-advanced').slider({
					range: true,
					min: min_price,
					max: max_price,
					values: [min_price, max_price],
					slide: function (event, ui) {

						var min_price_range = currency_symb + addCommas(ui.values[0]);
						var max_price_range = currency_symb + addCommas(ui.values[1]);

						$('.min-price-range-hidden').val( min_price_range );
						$('.max-price-range-hidden').val( max_price_range);

						$('.min-price-range').text( min_price_range );
						$('.max-price-range').text( max_price_range );

					},
					stop: function( event, ui ) {
						$( this ).closest( 'div.job_listings' ).triggerHandler( 'update_results', [ 1, false ] );
					}
				});

				var min_price_range = currency_symb + addCommas($('.price-range-advanced').slider('values', 0));
				var max_price_range = currency_symb + addCommas($('.price-range-advanced').slider('values', 1));

				$('.min-price-range').text(min_price_range);
				$('.max-price-range').text(max_price_range);

			}

			if ( $('.price-range-advanced').length ) {
				price_range( price_range_min, price_range_max );
			}

			$('.kw-controls-form [name^="search_sort"]').change( function() {
				kw_search_sort();
			});

			$( 'button.kw-update-form' ).on( $.knowhere.EVENT, function(e) {
				$(this).parents( 'form' ).submit();
			});

			$( 'form.job_search_form input' ).keypress(function(event) {
				if ( event.which == 13 ) {
					event.preventDefault();
					$( 'form.job_search_form' ).submit();
				}
			});
	}

		KnowhereJobManager.initLayoutControl = function () {

			var controls = $('.kw-listing-layout-control');
			if ( controls.length ) {
				KnowhereJobManager.initLayoutModule(controls);
			}

			$('.kw-layout-control').on($.knowhere.EVENT, function (t) {
				$(window).trigger('pxg:refreshmap'),
					t.preventDefault();

				var i = $(this).data('col'), n = [];
				$(this).siblings().each(function () {
					n.push($(this).data("col"));
				});

				var holder = $('.kw-flex-holder'),
					b = n[0], o = n[1];

				if ( o == 'kw-map-view' ) {
					$('.kw-finder-listings').removeClass('active-map-view');
				}

				holder.find('.job_listings').css('opacity', 0);
				holder.removeClass(b).removeClass(o).removeClass('kw-loading-opacity').addClass(i);
				$(this).addClass('kw-active').siblings().removeClass('kw-active');

				setTimeout(function () {
					holder.addClass('kw-loading-opacity');
					$('.kw-property-slideshow.owl-carousel').trigger('refresh.owl.carousel');
				}, 350);

			});

			$('.kw-search-adjust').on($.knowhere.EVENT, function (e) {
				e.preventDefault();

				var filters = $('.kw-finder-filters');
				if (!filters.length) return;

				var holder = $('.kw-flex-holder');

				if (!holder.is('.kw-moved')) {
					holder.addClass('kw-moved');
				} else {
					holder.removeClass('kw-moved');
				}
			});

		}

		KnowhereJobManager.initLayoutModule = function (controls) {
			controls.on( $.knowhere.EVENT, KnowhereJobManager.changeLayout );
		}

		KnowhereJobManager.changeLayout = function(e){

			var $this = $(this),
				container = $('.kw-listings'),
				items = container.find('.job_listing');

			if ( !items.length ) return false;

			$this
				.addClass('kw-active')
				.siblings('.kw-listing-layout-control')
				.removeClass('kw-active');

			container.removeClass('kw-grid-view kw-list-view').addClass('kw-' + $this.data('layout') + '-view');

			if ( container.hasClass('kw-isotope') ) container.isotope('layout');

			$(window).trigger('pxg:refreshmap');

			e.preventDefault();
			return false;
		}

		KnowhereJobManager.detailsNav = function() {

			$(".kw-additional-nav a")
				.add('#knowhere-write-review-button')
				.add('#kw-write-review-link')
				.on('click', function (e) {

					e.preventDefault();

					var el = $($(this).attr('href'));

					if ( el.length ) {
						var top = el.offset().top; top -= $('#header').outerHeight();
						$('body, html').animate( { scrollTop: top }, 600 );
					}

				});

		}

		KnowhereJobManager.contactForm = function() {


			$('#knowhere-detail-contact-form-btn').click(function(e) {

				e.preventDefault();

				var $this = $(this),
					$form = $this.parents( 'form' );

				$.ajax({
					type: 'post',
					url: knowhere_job_manager_localize.ajaxurl,
					data: $form.serialize(),
					method: $form.attr('method'),
					dataType: "JSON",
					beforeSend: function( ) { },
					success: function( result ) {
						if( result.success ) {
							$('.knowhere-contact-form-messages').empty().append(result.msg);
						} else {
							$('.knowhere-contact-form-messages').empty().append(result.msg);
						}
					}

				});
			});
		}

		KnowhereJobManager.update_breadcrumbs = function() {


			$('div.job_listings').on( 'update_breadcrumbs', function() {

				var target = $(this),
					form       = target.find( '.job_filters' ),
					results    = target.find('.kw-breadcrumb-container'),
					categories = form.find(':input[name^="search_categories"]').map(function() {
						return $(this).val();
					}).get(),
					data = {
						search_categories: categories
					};

				$.ajax({
					type: "POST",
					url: job_manager_ajax_filters.ajax_url.toString().replace( '%%endpoint%%', 'get_breadcrumbs' ),
					data: data,
					success: function ( result ) {

						if ( result ) {
							try {

								if ( result.html ) {
									results.replaceWith( result.html );
								}

							} catch(err) {
								if ( window.console ) {
									window.console.log( err );
								}
							}

						}

					},
					error: function ( jqXHR, textStatus, error ) {
						if ( window.console && 'abort' !== textStatus ) {
							window.console.log( textStatus + ': ' + error );
						}
					},
					statusCode: {
						404: function() {
							if ( window.console ) {
								window.console.log( 'Error 404: Ajax Endpoint cannot be reached.' );
							}
						}
					}
				});

			});

			$('#search_categories').change(function() {
				var target = $( this ).closest( 'div.job_listings' );
				target.triggerHandler( 'update_breadcrumbs' );
			});
		}

		KnowhereJobManager.popupLink = function(link) {

			if ( !$.isFunction($.fn.magnificPopup) ) return;

			var $link = link ? link : $('.kw-share-popup-link');

			if ( $link.length ) {
				$link.magnificPopup({
					type: 'inline',
					preloader: false,
					callbacks: {
						beforeOpen: function() {
						}
					}
				});
			}
		}

		KnowhereJobManager.openHoursToggle = function() {

			var $hoursHolder = $('.kw-hours-holder');

			if ( !$('.kw-hours-holder').length ) return;

			var $invisible = $('.kw-invisible-hours', $hoursHolder);

			$('.kw-switch-toggle').on($.knowhere.EVENT, function(e) {

				e.preventDefault();

				if ( $hoursHolder.hasClass('kw-visible') ) {
					$hoursHolder.removeClass('kw-visible');

					$invisible.stop().animate({
						'opacity' : 0
					}, 300, function () {
						$(this).slideUp(200);
					});

				} else {
					$hoursHolder.addClass('kw-visible');

					$invisible.stop().animate({
						'opacity' : 1
					}, 50, function () {
						$(this).slideDown(200);
					});

				}

			});

		}

		KnowhereJobManager.visible_search_jobs = function() {

			var $body = $('body');

			function visibleFilters(el) {

				var $filters = el ? $(el) : $('.job_filters');

				if ( $filters.length ) {
					$filters.addClass('visible-filters');
				}

			}

			if ( $body.hasClass('kw-using-facetwp') ) {

				visibleFilters();

				$(document).on('facetwp-refresh', function() {
					setTimeout(function() {
						visibleFilters();
					}, 10);
				});

			} else {

				$('.job_listings').on('update_results', function(  event, page, append, loading_previous ) {
					visibleFilters();
				});

				if ( $('.kw-listings-search .job_filters').length ) {
					visibleFilters('.kw-listings-search .job_filters');
				}

				$('.kw-listings-controls-wrap .kw-options-list.sort-param-orderby').on('click', 'li', function(e) {
					e.preventDefault();

					var $this = $(this),
						value = $this.data('value');
					if ( value ) {
						var target = $( this ).closest( 'div.job_listings' );
						target.data('orderby', value);
						target.triggerHandler( 'update_results', [ 1, false ] );
					}
				});

			}

		}

		KnowhereJobManager.profileFileUploader = function() {

			var $profileUploader = $('.profile-file-upload');

			if ( $profileUploader.length ) {

				$profileUploader.each(function(i, obj) {
					var $input = $(obj),
						id = $input.attr('id'),
						$label = $('label[for="' + id + '"]'),
						$btn = $('<div class="kw-file-input-field"><div class="kw-file-input-inner"><span class="lnr icon-picture kw-lead-icon"></span><span class="lnr icon-plus"></span>' + knowhere_job_manager_localize.strings['wp-job-manager-file-upload'] + '</div></div>').insertAfter($input);

					$btn.on('click', function() {
						$label.trigger('click');
					});
				});

				$('body').on( 'click', '.job-manager-profile-remove-uploaded-file', function() {
					$(this).closest( '.job-manager-uploaded-file' ).remove();
					return false;
				});

				$profileUploader.each(function() {
					$(this).fileupload({
						dataType: 'json',
						dropZone: $(this),
						url: knowhere_job_manager_localize.ajax_url.toString().replace( '%%endpoint%%', 'upload_file' ),
						maxNumberOfFiles: 1,
						formData: {
							script: true
						},
						add: function (e, data) {
							var $file_field     = $( this );
							var $form           = $file_field.closest( 'form' );
							var $uploaded_files = $file_field.parent().find('.job-manager-uploaded-files');
							var uploadErrors    = [];

							// Validate type
							var allowed_types = $(this).data('file_types');

							if ( allowed_types ) {
								var acceptFileTypes = new RegExp( '(\.|\/)(' + allowed_types + ')$', 'i' );

								if ( data.originalFiles[0].name.length && ! acceptFileTypes.test( data.originalFiles[0].name ) ) {
									uploadErrors.push( job_manager_ajax_file_upload.i18n_invalid_file_type + ' ' + allowed_types );
								}
							}

							if ( uploadErrors.length > 0 ) {
								window.alert( uploadErrors.join( '\n' ) );
							} else {
								$form.find(':input[type="submit"]').attr( 'disabled', 'disabled' );
								data.context = $('<progress value="" max="100"></progress>').appendTo( $uploaded_files );
								data.submit();
							}
						},
						progress: function (e, data) {
							var progress = parseInt(data.loaded / data.total * 100, 10);
							data.context.val( progress );
						},
						fail: function (e, data) {
							var $file_field     = $( this );
							var $form           = $file_field.closest( 'form' );

							if ( data.errorThrown ) {
								window.alert( data.errorThrown );
							}

							data.context.remove();

							$form.find(':input[type="submit"]').removeAttr( 'disabled' );
						},
						done: function (e, data) {
							var $file_field     = $( this );

							var $form           = $file_field.closest( 'form' );
							var $uploaded_files = $file_field.parent().find('.job-manager-uploaded-files');
							var image_types     = [ 'jpg', 'gif', 'png', 'jpeg', 'jpe' ];

							data.context.remove();

							// Handle JSON errors when success is false
							if( typeof data.result.success !== 'undefined' && ! data.result.success ){
								window.alert( data.result.data );
							}

							$.each(data.result.files, function(index, file) {
								if ( file.error ) {
									window.alert( file.error );
								} else {
									var html;

									if ( $.inArray( file.extension, image_types ) >= 0 ) {
										html = $.parseHTML( knowhere_job_manager_localize.js_field_html_img );
										$( html ).find('.job-manager-uploaded-file-preview img').attr( 'src', file.url );
									}

									$( html ).find('.input-text').val( file.url );
									$( html ).find('.input-text').attr( 'name', 'current_' + $file_field.attr( 'name' ) );

									$uploaded_files.html( html );
								}
							});

							$form.find(':input[type="submit"]').removeAttr( 'disabled' );
						}
					});
				});

			}

		}

	/*	DOM READY
	 /* --------------------------------------------- */

	$(function () {

		var $window = $(window), $body = $('body');

		if ( $('#job_preview').length ) {
			$body.addClass('single-job_listing single-job_listing_preview');
			$window.trigger('pxg:refreshmap');
			$window.trigger('debouncedresize');
			$('#job_preview').css('opacity', 1);
		}

		$('.kw-button-view').on( $.knowhere.EVENT, function (e) {
			e.preventDefault();

			if ( !$body.hasClass('kw-show-map') ) {
				$body.addClass('kw-show-map');
			} else {
				$body.removeClass('kw-show-map');
			}

			$('html, body').scrollTop(0);

			setTimeout(function() {
				$window.trigger('pxg:refreshmap');
			});

		});

		$('.kw-button-filter').on($.knowhere.EVENT, function (e) {
			e.preventDefault();

			if ( $body.hasClass('kw-show-filters') ) {
				$window.scrollTop(0);
			}
			$body.toggleClass('kw-show-filters');
		});

		$('.kw-show-more-list-button').on($.knowhere.EVENT, function(e) {
			e.preventDefault();

			var $this = $(this);
			var $content = $this.parents('.kw-categories-item-list').children('li.kw-list-item');
			var linkData = $this.data('show');
			// var container = $('.kw-categories-inner');

			if ( linkData == 'more' ) {
				// linkData = $this.data('show', 'less');
				$this.removeClass('kw-more-list').addClass('kw-less-list');
				$content.removeClass('kw-show-less-list').addClass('kw-show-more-list');
				var linkText = knowhere_job_manager_localize.i18n.show_less;
			} else {
				// linkData = $this.data('show', 'more');
				$this.removeClass('kw-less-list').addClass('kw-more-list');
				$content.removeClass('kw-show-more-list').addClass('kw-show-less-list');
				var linkText = knowhere_job_manager_localize.i18n.show_more;
			}

			$this.text(linkText);

		});

		KnowhereJobManager.popupLink();
		KnowhereJobManager.detailsNav();
		KnowhereJobManager.contactForm();
		KnowhereJobManager.visible_search_jobs();
		KnowhereJobManager.openHoursToggle();
		KnowhereJobManager.profileFileUploader();
		KnowhereJobManager.update_breadcrumbs();

	});

	$(window).load(function() {

		KnowhereJobManager.init();
		KnowhereJobManager.initScroll();

		$('.knowhere-tooltip-trigger').on($.knowhere.EVENT, function(e) {
			e.preventDefault();
			$(this).parents('form').toggleClass('active');
		});

		var $bookmarks_form = $('.wp-job-manager-bookmarks-form');

		$(document).on('click.tooltipFocusOut', function(e) {
			if ( $bookmarks_form.hasClass('active') && !$(e.target).closest($bookmarks_form).length ) {
				e.preventDefault();
				$bookmarks_form.removeClass('active');
			}
		});

	});

})(window, jQuery);