<?php
/**
 * Widget: Listing Contact Form
 *
 */
class Knowhere_Widget_Listing_Contact_Form extends Knowhere_Widget {

	public function __construct() {

		$this->widget_description = esc_html__( 'Display contact form for detail listing, agent, agency, candidate.', 'knowherepro' );
		$this->widget_id          = 'knowhere_listing_contact_form';
		$this->widget_cssclass    = 'kw-listing-contact-form';
		$this->widget_name        = '&#x27A4; ' . esc_html__( 'Listing', 'knowherepro' ) . '  - ' . esc_html__( 'Listing Contact Form', 'knowherepro' );
		$this->settings           = array(
			'title' => array(
				'type'  => 'text',
				'std'   => esc_html__( 'Contact Form', 'knowherepro' ),
				'label' => esc_html__( 'Title:', 'knowherepro' )
			)
		);
		parent::__construct();
	}

	function widget( $args, $instance ) {

		extract( $args );

		$email = ' ';

		if ( is_singular('job_listing') || get_query_var('company') ) {
			$email = get_post_meta(get_the_ID(), '_application', true);
		}

		if ( is_singular('resume') ) {
			$email = get_post_meta(get_the_ID(), '_candidate_email', true);
		}

		if ( is_singular('knowhere_agency') ) {
			$email = sanitize_email(get_post_meta(get_the_ID(), 'knowhere_agency_email', true));
		}

		if ( is_singular('knowhere_agent') ) {
			$email = sanitize_email( get_post_meta( get_the_ID(), 'knowhere_agent_email', true ) );
		}

		$title = apply_filters( 'widget_title', isset( $instance['title'] ) ? $instance['title'] : '', $instance, $this->id_base );

		ob_start();

		echo $before_widget;

		if ( is_email( $email ) ): ?>

			<?php if ( $title ) echo $before_title . sanitize_text_field($title) . $after_title; ?>

			<form method="post" action="" class="knowhere-detail-contact-form" id="knowhere-detail-contact-form">
				<input type="hidden" id="target_email" name="target_email" value="<?php echo antispambot($email); ?>">
				<input type="hidden" name="knowhere-detail-ajax-nonce" id="knowhere-detail-ajax-nonce" value="<?php echo wp_create_nonce('knowhere-contact-form-nonce'); ?>"/>
				<input type="hidden" name="action" value="knowhere_listing_contact_form" />

				<div class="form-group">
					<label for="name"><?php esc_html_e( 'Name', 'knowherepro' ); ?> <abbr class="required">*</abbr></label>
					<input type="text" name="name" id="name" class="form-control">
				</div>

				<div class="form-group">
					<label for="email"><?php esc_html_e( 'Email', 'knowherepro' ); ?> <abbr class="required">*</abbr></label>
					<input type="email" name="email" id="email" class="form-control">
				</div>

				<div class="form-group">
					<label for="phone"><?php esc_html_e( 'Phone', 'knowherepro' ); ?></label>
					<input type="text" name="phone" id="phone" class="form-control">
				</div>

				<div class="form-group">
					<label for="message"><?php echo esc_html__('Your Message', 'knowherepro'); ?> <abbr class="required">*</abbr></label>
					<textarea name="message" id="message" rows="3" class="form-control"></textarea>
				</div>

				<div class="form-group">
					<button type="submit" id="knowhere-detail-contact-form-btn" class="kw-btn-medium kw-theme-color knowhere-detail-contact-form-btn"><?php esc_html_e('Send Message', 'knowherepro'); ?></button>
					<div class="knowhere-contact-form-messages"></div>
				</div>

			</form>

		<?php endif; ?>

		<?php

		echo $after_widget;

		wp_reset_postdata();

		$content = ob_get_clean();

		echo apply_filters( $this->widget_id, $content );
	}
}
